You are viewing a plain text version of this content. The canonical link for it is here.
Posted to cvs@httpd.apache.org by ja...@apache.org on 2021/12/26 09:52:26 UTC

svn commit: r1896409 - in /httpd/httpd/trunk/modules/md: md.h md_acme.c md_acme_authz.c md_acmev2_drive.c md_crypt.c md_ocsp.c md_reg.c md_store_fs.c mod_md.c

Author: jailletc36
Date: Sun Dec 26 09:52:25 2021
New Revision: 1896409

URL: http://svn.apache.org/viewvc?rev=1896409&view=rev
Log:
Fix some typo.

Add some missing spaces spotted here and there to better comply with coding style

Modified:
    httpd/httpd/trunk/modules/md/md.h
    httpd/httpd/trunk/modules/md/md_acme.c
    httpd/httpd/trunk/modules/md/md_acme_authz.c
    httpd/httpd/trunk/modules/md/md_acmev2_drive.c
    httpd/httpd/trunk/modules/md/md_crypt.c
    httpd/httpd/trunk/modules/md/md_ocsp.c
    httpd/httpd/trunk/modules/md/md_reg.c
    httpd/httpd/trunk/modules/md/md_store_fs.c
    httpd/httpd/trunk/modules/md/mod_md.c

Modified: httpd/httpd/trunk/modules/md/md.h
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/modules/md/md.h?rev=1896409&r1=1896408&r2=1896409&view=diff
==============================================================================
--- httpd/httpd/trunk/modules/md/md.h (original)
+++ httpd/httpd/trunk/modules/md/md.h Sun Dec 26 09:52:25 2021
@@ -95,7 +95,7 @@ struct md_t {
     struct apr_array_header_t *cert_files; /* != NULL iff pubcerts explicitly configured */
     struct apr_array_header_t *pkey_files; /* != NULL iff privkeys explicitly configured */
     const char *ca_eab_kid;         /* optional KEYID for external account binding */
-    const char *ca_eab_hmac;        /* optional HMAC for external accont binding */
+    const char *ca_eab_hmac;        /* optional HMAC for external account binding */
 
     md_state_t state;               /* state of this MD */
     const char *state_descr;        /* description of state of NULL */

Modified: httpd/httpd/trunk/modules/md/md_acme.c
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/modules/md/md_acme.c?rev=1896409&r1=1896408&r2=1896409&view=diff
==============================================================================
--- httpd/httpd/trunk/modules/md/md_acme.c (original)
+++ httpd/httpd/trunk/modules/md/md_acme.c Sun Dec 26 09:52:25 2021
@@ -714,7 +714,7 @@ static apr_status_t update_directory(con
         /* RFC 8555 only requires "directory" and "newNonce" resources.
          * mod_md uses "newAccount" and "newOrder" so check for them.
          * But mod_md does not use the "revokeCert" or "keyChange"
-         * resources, so tolerate the absense of those keys.  In the
+         * resources, so tolerate the absence of those keys.  In the
          * future if mod_md implements revocation or key rollover then
          * the use of those features should be predicated on the
          * server's advertised capabilities. */

Modified: httpd/httpd/trunk/modules/md/md_acme_authz.c
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/modules/md/md_acme_authz.c?rev=1896409&r1=1896408&r2=1896409&view=diff
==============================================================================
--- httpd/httpd/trunk/modules/md/md_acme_authz.c (original)
+++ httpd/httpd/trunk/modules/md/md_acme_authz.c Sun Dec 26 09:52:25 2021
@@ -334,7 +334,7 @@ static apr_status_t cha_tls_alpn_01_setu
 
     /* Create a "tls-alpn-01" certificate for the domain we want to authenticate.
      * The server will need to answer a TLS connection with SNI == authz->domain
-     * and ALPN procotol "acme-tls/1" with this certificate.
+     * and ALPN protocol "acme-tls/1" with this certificate.
      */
     md_data_init_str(&data, cha->key_authz);
     rv = md_crypt_sha256_digest_hex(&token, p, &data);

Modified: httpd/httpd/trunk/modules/md/md_acmev2_drive.c
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/modules/md/md_acmev2_drive.c?rev=1896409&r1=1896408&r2=1896409&view=diff
==============================================================================
--- httpd/httpd/trunk/modules/md/md_acmev2_drive.c (original)
+++ httpd/httpd/trunk/modules/md/md_acmev2_drive.c Sun Dec 26 09:52:25 2021
@@ -169,7 +169,7 @@ retry:
     if (APR_SUCCESS != rv) goto leave;
     
     if (!ad->order->certificate) {
-        md_result_set(result, APR_EINVAL, "Order valid, but certifiate url is missing.");
+        md_result_set(result, APR_EINVAL, "Order valid, but certificate url is missing.");
         goto leave;
     }
     md_result_set(result, APR_SUCCESS, NULL);

Modified: httpd/httpd/trunk/modules/md/md_crypt.c
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/modules/md/md_crypt.c?rev=1896409&r1=1896408&r2=1896409&view=diff
==============================================================================
--- httpd/httpd/trunk/modules/md/md_crypt.c (original)
+++ httpd/httpd/trunk/modules/md/md_crypt.c Sun Dec 26 09:52:25 2021
@@ -1518,7 +1518,7 @@ apr_status_t md_cert_chain_read_http(str
         rv = md_cert_read_chain(chain, res->req->pool, data, data_len);
         if (APR_SUCCESS == rv && chain->nelts == 0) {
             md_log_perror(MD_LOG_MARK, MD_LOG_ERR, 0, p,
-                "certificiate chain response did not contain any certificates "
+                "certificate chain response did not contain any certificates "
                 "(suspicious content-type: %s)", ct);
             rv = APR_ENOENT;
         }

Modified: httpd/httpd/trunk/modules/md/md_ocsp.c
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/modules/md/md_ocsp.c?rev=1896409&r1=1896408&r2=1896409&view=diff
==============================================================================
--- httpd/httpd/trunk/modules/md/md_reg.c (original)
+++ httpd/httpd/trunk/modules/md/md_reg.c Sun Dec 26 09:52:25 2021
@@ -243,7 +243,7 @@ static apr_status_t state_init(md_reg_t
         }
         else {
             state = MD_S_ERROR;
-            state_descr = "error intializing";
+            state_descr = "error initializing";
             md_log_perror(MD_LOG_MARK, MD_LOG_WARNING, rv, p, "md{%s}: error", md->name);
             goto cleanup;
         }

Modified: httpd/httpd/trunk/modules/md/md_store_fs.c
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/modules/md/md_store_fs.c?rev=1896409&r1=1896408&r2=1896409&view=diff
==============================================================================
--- httpd/httpd/trunk/modules/md/md_store_fs.c (original)
+++ httpd/httpd/trunk/modules/md/md_store_fs.c Sun Dec 26 09:52:25 2021
@@ -240,8 +240,8 @@ static apr_status_t read_store_file(md_s
             if (APR_SUCCESS == rv) {
                 md_json_setn(MD_STORE_VERSION, json, MD_KEY_STORE, MD_KEY_VERSION, NULL);
                 rv = md_json_freplace(json, ptemp, MD_JSON_FMT_INDENT, fname, MD_FPROT_F_UONLY);
-           }
-           md_log_perror(MD_LOG_MARK, MD_LOG_INFO, rv, p, "migrated store");
+            }
+            md_log_perror(MD_LOG_MARK, MD_LOG_INFO, rv, p, "migrated store");
         } 
     }
     return rv;

Modified: httpd/httpd/trunk/modules/md/mod_md.c
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/modules/md/mod_md.c?rev=1896409&r1=1896408&r2=1896409&view=diff
==============================================================================
--- httpd/httpd/trunk/modules/md/mod_md.c (original)
+++ httpd/httpd/trunk/modules/md/mod_md.c Sun Dec 26 09:52:25 2021
@@ -98,7 +98,7 @@ static void log_print(const char *file,
         buffer[LOG_BUF_LEN-1] = '\0';
 
         if (log_server) {
-            ap_log_error(file, line, APLOG_MODULE_INDEX, (int)level, rv, log_server, "%s",buffer);
+            ap_log_error(file, line, APLOG_MODULE_INDEX, (int)level, rv, log_server, "%s", buffer);
         }
         else {
             ap_log_perror(file, line, APLOG_MODULE_INDEX, (int)level, rv, p, "%s", buffer);
@@ -1167,7 +1167,7 @@ static apr_status_t get_certificates(ser
             }
             else if (APR_STATUS_IS_ENOENT(rv)) {
                 /* certificate for this pkey is not available, others might
-                 * if pkeys have been added for a runnign mdomain.
+                 * if pkeys have been added for a running mdomain.
                  * see issue #260 */
                 rv = APR_SUCCESS;
             }
--- httpd/httpd/trunk/modules/md/md_ocsp.c (original)
+++ httpd/httpd/trunk/modules/md/md_ocsp.c Sun Dec 26 09:52:25 2021
@@ -449,7 +449,7 @@ static void ocsp_get_meta(md_ocsp_cert_s
 {
     apr_thread_mutex_lock(reg->mutex);
     if (ostat->resp_der.len <= 0) {
         /* No resonse known, check the store if out watchdog retrieved one 
          * in the meantime. */
         ocsp_status_refresh(ostat, p);
     }
@@ -640,7 +640,7 @@ static apr_status_t ostat_on_resp(const
     switch ((n = OCSP_check_nonce(ostat->ocsp_req, basic_resp))) {
         case 1:
             md_log_perror(MD_LOG_MARK, MD_LOG_TRACE3, 0, req->pool,
-                          "req[%d]: OCSP respoonse nonce does match", req->id);
+                          "req[%d]: OCSP response nonce does match", req->id);
             break;
         case 0:
             rv = APR_EINVAL;
@@ -650,7 +650,7 @@ static apr_status_t ostat_on_resp(const
             
         case -1:
             md_log_perror(MD_LOG_MARK, MD_LOG_TRACE3, 0, req->pool,
-                          "req[%d]: OCSP respoonse did not return the nonce", req->id);
+                          "req[%d]: OCSP response did not return the nonce", req->id);
             break;
         default:
             break;
@@ -449,7 +449,7 @@ static void ocsp_get_meta(md_ocsp_cert_s
     apr_thread_mutex_lock(reg->mutex);
     if (ostat->resp_der.len <= 0) {
-        /* No resonse known, check the store if out watchdog retrieved one 
+        /* No response known, check the store if out watchdog retrieved one 
          * in the meantime. */
         ocsp_status_refresh(ostat, p);

Modified: httpd/httpd/trunk/modules/md/md_reg.c
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/modules/md/md_reg.c?rev=1896409&r1=1896408&r2=1896409&view=diff
==============================================================================